/* -*- C++ -*-
 
  This file is part of ViPEC
  Copyright (C) 1991-2000 Johan Rossouw (jrossouw@alcatel.altech.co.za)
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU Library General Public License as
  published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU Library General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
*/

#include <SchematicElement.h>

#include <iostream>

//-----------------------------------------------------------------
SchematicElement::SchematicElement()
    : isSelected_( FALSE )
{}

//-----------------------------------------------------------------
SchematicElement::~SchematicElement()
{
}

//-----------------------------------------------------------------
bool SchematicElement::isSelected() const
  {
    return isSelected_;
  }

//-----------------------------------------------------------------
void SchematicElement::setSelected( bool isSelected )
{
  isSelected_ = isSelected;
}
